diff --git a/docs/gst/gstreamer-docs.sgml b/docs/gst/gstreamer-docs.sgml
index 2c234ebae6..6693281518 100644
--- a/docs/gst/gstreamer-docs.sgml
+++ b/docs/gst/gstreamer-docs.sgml
@@ -99,6 +99,8 @@ with some more specialized elements.
&GstElementFactory;
&GstEvent;
&GstFormat;
+ &GstIndex;
+ &GstIndexFactory;
&GstInfo;
&GstObject;
&GstPad;
@@ -109,15 +111,13 @@ with some more specialized elements.
&GstPluginFeature;
&GstProbe;
&GstProps;
- &GstQueue;
&GstQuery;
+ &GstQueue;
&GstRegistry;
&GstScheduler;
&GstSchedulerFactory;
&GstSystemClock;
&GstThread;
- &GstIndex;
- &GstIndexFactory;
&GstType;
&GstTypeFactory;
&GstTypeFind;
diff --git a/docs/gst/gstreamer-sections.txt b/docs/gst/gstreamer-sections.txt
index 409a681607..13a509a6c0 100644
--- a/docs/gst/gstreamer-sections.txt
+++ b/docs/gst/gstreamer-sections.txt
@@ -32,14 +32,13 @@ cothread_current
gstatomic
GstAtomicInt
-GST_ATOMIC_INT_INIT
-GST_ATOMIC_INT_FREE
-GST_ATOMIC_INT_SET
-GST_ATOMIC_INT_VALUE
-GST_ATOMIC_INT_READ
-GST_ATOMIC_INT_INC
-GST_ATOMIC_INT_DEC_AND_TEST
-GST_ATOMIC_INT_ADD
+gst_atomic_int_init
+gst_atomic_int_destroy
+gst_atomic_int_set
+gst_atomic_int_read
+gst_atomic_int_add
+gst_atomic_int_inc
+gst_atomic_int_dec_and_test
@@ -192,10 +191,13 @@ GstSchedulerFactoryClass
gstformat
GstFormat
GstFormat
+GST_FORMAT_PERCENT_MAX
+GST_FORMAT_PERCENT_SCALE
GstFormatDefinition
GST_FORMATS_FUNCTION
gst_format_register
gst_format_get_by_nick
+gst_formats_contains
gst_format_get_details
gst_format_get_definitions
@@ -277,7 +279,6 @@ GstDataFlags
GST_DATA_IS_READONLY
GST_DATA_REFCOUNT
GST_DATA_REFCOUNT_VALUE
-GST_DATA_REFCOUNT_READ
GST_DATA_COPY_FUNC
GST_DATA_FREE_FUNC
gst_data_init
@@ -810,7 +811,14 @@ gst_object_flags_get_type
gstquery
GstQueryType
+GST_QUERY_TYPE_RATE_DEN
+GstQueryTypeDefinition
GST_QUERY_TYPE_FUNCTION
+gst_query_type_register
+gst_query_type_get_by_nick
+gst_query_types_contains
+gst_query_type_get_details
+gst_query_type_get_definitions
diff --git a/docs/gst/tmpl/gstatomic.sgml b/docs/gst/tmpl/gstatomic.sgml
index 6ffe92d75f..79380e6a99 100644
--- a/docs/gst/tmpl/gstatomic.sgml
+++ b/docs/gst/tmpl/gstatomic.sgml
@@ -2,13 +2,16 @@
GstAtomic
-Macros that implement atomic operations
+Functions that implement atomic operations.
-GstAtomic contains a set of macros that can be used to implement
-atomic algorithms that are thread safe and don't use heavyweight
-locking mechanisms.
+Functions that implement atomic operations on a #GstAtomicInt structure.
+Atomic operations are thread safe and don't use heavyweight locking mechanisms.
+
+
+These functions will be inlined in the GStreamer core but are available to plugins
+as external methods.
@@ -22,74 +25,68 @@ A structure that contains an integer that can be modified
atomically.
+@lock:
-
+
-Initialize an atomic int
+Initialize an allocated #GstAtomicInt with a value. Call this method
+only once as it will allocate a mutex in the C-fallback case.
-@ref: a reference to a #GstAtomicInt
-@val: The initial value for the integer
+@aint: a #GstAtomicInt
+@val: a new value
-
+
-Free the memory allocated by #GST_ATOMIC_INT_INIT
+Destroy a #GstAtomicInt. Call this method only once as it will
+free the mutex in the C-fallback case.
-@ref: A reference to a #GstAtomicInt
+@aint: a #GstAtomicInt
-
+
-Set the value of a #GstAtomicInt atomically
+Atomically set the value on the #GstAtomicInt.
-@ref: a reference to a #GstAtomicInt
-@val: The value for the integer
+@aint: a #GstAtomicInt
+@val: The new value
-
+
-Get the value of a #GstAtomicInt atomically
+Atomically read the contents of a #GstAtomicInt
-@ref: a reference to a #GstAtomicInt
+@aint: a #GstAtomicInt
+@Returns: the value of the atomic int
-
+
-Get the value of a #GstAtomicInt atomically into a variable
+Atomically add the given value to the #GstAtomicInt.
-@ref: a reference to a #GstAtomicInt
-@res: a pointer to a gint to hold the value
+@aint: a #GstAtomicInt
+@val: the value to add
-
+
-Increment the value of a #GstAtomicInt atomically
+Atomically increment the #GstAtomicInt
-@ref: a reference to a #GstAtomicInt
+@aint: a #GstAtomicInt
-
+
-Decrement the value of a #GstAtomicInt atomically and test
-for zero.
+Atomically decrement the #GstAtomicInt and test if it is zero.
-@ref: a reference to a #GstAtomicInt
-@zero: a gpointer to a gboolean to hold the value of the test
-
-
-
-
-Atomically add a value to a #GstAtomicInt
-
-
-@ref: a reference to a #GstAtomicInt
-@count: The value to add
+@aint: a #GstAtomicInt
+@Returns: TRUE if the atomic int is 0
diff --git a/docs/gst/tmpl/gstbin.sgml b/docs/gst/tmpl/gstbin.sgml
index 38a41423a8..b6eda534c4 100644
--- a/docs/gst/tmpl/gstbin.sgml
+++ b/docs/gst/tmpl/gstbin.sgml
@@ -34,7 +34,10 @@ After the bin has been set to the PLAYING state (with gst_element_set_state()),
gst_bin_iterate() is used to process the elements in the bin.
-The "object_added" signal is fired whenever a new object is added to the bin.
+The "element_added" signal is fired whenever a new element is added to the bin.
+
+
+The "element_removed" signal is fired whenever an element is removed from the bin.
gst_bin_destroy() is used to destroy the bin.
@@ -225,7 +228,7 @@ Free the memory allocated by this bin
@gstbin: the object which received the signal.
-@arg1:
+@arg1: the element that was added to the bin
@@ -233,5 +236,5 @@ Free the memory allocated by this bin
@gstbin: the object which received the signal.
-@arg1:
+@arg1: the element that was removed from the bin
diff --git a/docs/gst/tmpl/gstdata.sgml b/docs/gst/tmpl/gstdata.sgml
index 7790714254..a2570a2626 100644
--- a/docs/gst/tmpl/gstdata.sgml
+++ b/docs/gst/tmpl/gstdata.sgml
@@ -137,15 +137,6 @@ Get the current refcount value
@data: The GstData to query
-
-
-Read the current refcount value into the specified value
-
-
-@data: The GstData to get the refcount value of
-@value: A pointer to a gint to hold the refcount value
-
-
Get access to the copy function of the data
diff --git a/docs/gst/tmpl/gstevent.sgml b/docs/gst/tmpl/gstevent.sgml
index 3c530027f1..bdc07382c0 100644
--- a/docs/gst/tmpl/gstevent.sgml
+++ b/docs/gst/tmpl/gstevent.sgml
@@ -382,7 +382,7 @@ Create a new flush event.
A convenience macro to create event mask functions
-@type:
+@type: The type of the first argument of the function
@functionname: the name of the function
@...: event masks, the last element is marked with 0
diff --git a/docs/gst/tmpl/gstformat.sgml b/docs/gst/tmpl/gstformat.sgml
index 597073a5a1..3d7c6d9d05 100644
--- a/docs/gst/tmpl/gstformat.sgml
+++ b/docs/gst/tmpl/gstformat.sgml
@@ -12,7 +12,7 @@ formats can be used to perform seeking or conversions/query operations.
-
+#GstPad, #GstElement
@@ -29,6 +29,21 @@ Standard predefined formats
@GST_FORMAT_UNITS: frames for video, samples for audio, other definitions as
defined by the media type.
+
+
+The PERCENT format is between 0 and this value
+
+
+
+
+
+
+The value used to scale down the reported PERCENT format value to
+its real value.
+
+
+
+
A format definition
@@ -68,6 +83,16 @@ of formats.
@Returns:
+
+
+
+
+
+@formats:
+@format:
+@Returns:
+
+
diff --git a/docs/gst/tmpl/gstindex.sgml b/docs/gst/tmpl/gstindex.sgml
index b56909a798..549f4a80ca 100644
--- a/docs/gst/tmpl/gstindex.sgml
+++ b/docs/gst/tmpl/gstindex.sgml
@@ -12,7 +12,7 @@ in a pipeline.
-
+#GstIndexFactory
@@ -108,9 +108,10 @@ An association in an entry.
flags for an association entry
-@GST_ACCOCIATION_FLAG_NONE: no flags
-@GST_ACCOCIATION_FLAG_KEY_UNIT: this entry marks a key unit.
-@GST_ACCOCIATION_FLAG_LAST:
+@GST_ASSOCIATION_FLAG_NONE: no extra flags
+@GST_ASSOCIATION_FLAG_KEY_UNIT: the entry marks a key unit, a key unit is one
+ that marks a place where one can randomly seek to.
+@GST_ASSOCIATION_FLAG_LAST: extra user defined flags should start here.
diff --git a/docs/gst/tmpl/gstpad.sgml b/docs/gst/tmpl/gstpad.sgml
index 61256074fc..a94945edb0 100644
--- a/docs/gst/tmpl/gstpad.sgml
+++ b/docs/gst/tmpl/gstpad.sgml
@@ -374,7 +374,7 @@ Flags for the pad.
@GST_PAD_DISABLED: the pad is disabled.
-@GST_PAD_EOS: the pad is in end of stream state.
+@GST_PAD_NEGOTIATING:
@GST_PAD_FLAG_LAST: subclasses can use this number to enumerate their flags.
diff --git a/docs/gst/tmpl/gstquery.sgml b/docs/gst/tmpl/gstquery.sgml
index 9464f06294..07925836c5 100644
--- a/docs/gst/tmpl/gstquery.sgml
+++ b/docs/gst/tmpl/gstquery.sgml
@@ -20,14 +20,30 @@ Query types can be used to perform queries on pads and elements.
Standard predefined Query types
-@GST_QUERY_NONE:
-@GST_QUERY_TOTAL:
-@GST_QUERY_POSITION:
-@GST_QUERY_LATENCY:
-@GST_QUERY_JITTER:
-@GST_QUERY_START:
-@GST_QUERY_SEGMENT_END:
-@GST_QUERY_RATE:
+@GST_QUERY_NONE: invalid query type
+@GST_QUERY_TOTAL: total length of stream
+@GST_QUERY_POSITION: current position in stream
+@GST_QUERY_LATENCY: latency of stream
+@GST_QUERY_JITTER: current jitter of stream
+@GST_QUERY_START: start of configured segment
+@GST_QUERY_SEGMENT_END: end of configured segment
+@GST_QUERY_RATE: current rate of the stream
+
+
+
+Rates are relative to this value
+
+
+
+
+
+
+A Query Type definition
+
+
+@value: the unique id of the Query type
+@nick: a short nick
+@description: a longer description of the query type
@@ -39,3 +55,49 @@ Convenience function to define a function that returns an array of query types.
@...: query types, 0 to end the list
+
+
+
+
+
+@nick:
+@description:
+@Returns:
+
+
+
+
+
+
+
+@nick:
+@Returns:
+
+
+
+
+
+
+
+@types:
+@type:
+@Returns:
+
+
+
+
+
+
+
+@type:
+@Returns:
+
+
+
+
+
+
+
+@Returns:
+
+
diff --git a/docs/gst/tmpl/gstreamer-unused.sgml b/docs/gst/tmpl/gstreamer-unused.sgml
index fe9d9dfff1..410201ba5d 100644
--- a/docs/gst/tmpl/gstreamer-unused.sgml
+++ b/docs/gst/tmpl/gstreamer-unused.sgml
@@ -1443,6 +1443,68 @@ g_print messages.
@klass:
+
+
+Atomically add a value to a #GstAtomicInt
+
+
+@ref: a reference to a #GstAtomicInt
+@count: The value to add
+
+
+
+Decrement the value of a #GstAtomicInt atomically and test
+for zero.
+
+
+@ref: a reference to a #GstAtomicInt
+@zero: a gpointer to a gboolean to hold the value of the test
+
+
+
+Free the memory allocated by #GST_ATOMIC_INT_INIT
+
+
+@ref: A reference to a #GstAtomicInt
+
+
+
+Increment the value of a #GstAtomicInt atomically
+
+
+@ref: a reference to a #GstAtomicInt
+
+
+
+Initialize an atomic int
+
+
+@ref: a reference to a #GstAtomicInt
+@val: The initial value for the integer
+
+
+
+Get the value of a #GstAtomicInt atomically into a variable
+
+
+@ref: a reference to a #GstAtomicInt
+@res: a pointer to a gint to hold the value
+
+
+
+Set the value of a #GstAtomicInt atomically
+
+
+@ref: a reference to a #GstAtomicInt
+@val: The value for the integer
+
+
+
+Get the value of a #GstAtomicInt atomically
+
+
+@ref: a reference to a #GstAtomicInt
+
@@ -1735,6 +1797,14 @@ A flag indicating that SSE instructions are supported.
+
+
+Read the current refcount value into the specified value
+
+
+@data: The GstData to get the refcount value of
+@value: A pointer to a gint to hold the refcount value
+
diff --git a/docs/gst/tmpl/gstxml.sgml b/docs/gst/tmpl/gstxml.sgml
index 32d00bc1f9..08450b21b9 100644
--- a/docs/gst/tmpl/gstxml.sgml
+++ b/docs/gst/tmpl/gstxml.sgml
@@ -110,6 +110,10 @@ All GstElements can be serialized to an XML presentation and subsequently loaded
+@:
+@:
+@:
+
@gstxml: the object which received the signal.
@arg1:
@arg2:
@@ -119,7 +123,7 @@ All GstElements can be serialized to an XML presentation and subsequently loaded
-@:
-@:
-@:
+@gstxml: the object which received the signal.
+@arg1:
+@arg2:
diff --git a/gst/gstquery.c b/gst/gstquery.c
index 64c3bf16f9..ca8497bbf6 100644
--- a/gst/gstquery.c
+++ b/gst/gstquery.c
@@ -124,25 +124,25 @@ gst_query_type_get_by_nick (const gchar *nick)
}
/**
* gst_queries_contains:
* @queries: The query array to search
* @query: the query to find
*
* See if the given query is inside the query array.
*
* Returns: TRUE if the query is found inside the array
*/
gboolean
-gst_queries_contains (const GstQueryType *queries, GstQueryType query)
+gst_query_types_contains (const GstQueryType *types, GstQueryType type)
{
- if (!queries)
+ if (!types)
return FALSE;
- while (*queries) {
- if (*queries == query)
+ while (*types) {
+ if (*types == type)
return TRUE;
- queries++;
+ types++;
}
return FALSE;
}
@@ -150,16 +150,16 @@ gst_queries_contains (const GstQueryType *queries, GstQueryType query)
/**
* gst_query_type_get_details:
- * @query: The query to get details of
+ * @type: The query to get details of
*
* Get details about the given query.
*
* Returns: The #GstQueryTypeDefinition for @query or NULL on failure.
*/
const GstQueryTypeDefinition*
-gst_query_type_get_details (GstQueryType query)
+gst_query_type_get_details (GstQueryType type)
{
- return g_hash_table_lookup (_query_type_to_nick, GINT_TO_POINTER (query));
+ return g_hash_table_lookup (_query_type_to_nick, GINT_TO_POINTER (type));
}
/**
@@ -124,25 +124,25 @@ gst_query_type_get_by_nick (const gchar *nick)
}
/**
- * gst_queries_contains:
- * @queries: The query array to search
- * @query: the query to find
+ * gst_query_types_contains:
+ * @types: The query array to search
+ * @type: the querytype to find
*
* See if the given query is inside the query array.